#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Créé le Sun May  8 16:45:40 2022

@auteur: david ALBERTO
(www.astrolabe-science.fr)
"""
import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
from matplotlib import ticker# mise en forme des graduations secondaires


# Paramètres utilisateur :
# couleurs :
c_stables = 'k'
c_alpha = 'yellowgreen'
c_beta_m = 'dodgerblue'
c_beta_p = 'magenta' 
c_capt_e = 'darkorange'
c_fission = 'crimson'
c_em_proton = 'darkmagenta'
c_em_neutron = 'darkgoldenrod'

marqueur='o'# forme du point (par défaut : 'o' (rond))

taille_pt = 6
graduations=True

#plt.rcParams["font.family"] = "Roboto" # ou autre police installée
plt.rcParams.update({"text.usetex": True}) 
Zmax=118
Nmax=179
# ----------------------------------
donnees=pd.read_csv("data_decay_mode.csv",
                    skiprows=27,
                    sep="\t",
                    usecols=[2,3,4],
                    names=['Z','N','mode']
                    )

donnees = donnees[donnees['Z'] <=Zmax]# filtrer les valeurs de Z

# Les listes suivantes accueilleront les coordonnées (Z,N) par type de désintégration
noyaux_alpha = []
noyaux_beta_m = []
noyaux_beta_p = []
noyaux_capt_e = []
noyaux_stables = []
noyaux_em_proton = []
noyaux_em_neutron = []
noyaux_fission = []

# balayage du tableau de données :
for i in donnees.index :
    type=donnees['mode'][i]
    Z = donnees['Z'][i]
    N = donnees['N'][i]
    if 'A' in type:
        noyaux_alpha.append((Z,N))
    elif 'B-' in type:
        noyaux_beta_m.append((Z, N))
    elif 'B+' in type:
        noyaux_beta_p.append((Z, N))
    elif 'EC' in type:
        noyaux_capt_e.append((Z, N))
    elif 'IS' in type:
        noyaux_stables.append((Z, N))
    elif 'SF' in type:
        noyaux_fission.append((Z, N))
    elif 'p' in type:
        noyaux_em_proton.append((Z, N))
    elif 'n' in type:
        noyaux_em_neutron.append((Z, N))

effectif = len(noyaux_alpha)+len(noyaux_beta_m)+len(noyaux_beta_p)+len(noyaux_capt_e)+len(noyaux_stables)+len(noyaux_em_neutron)+len(noyaux_em_proton)+len(noyaux_fission)

def trace(liste, couleur, label):
    X, Y = zip(*liste)
    ax.scatter(X,Y,c=couleur, s=taille_pt, marker=marqueur, label=label)

# -----------------------------------------
# PARAMETRES DU GRAPHIQUE
fig=plt.figure(figsize=(8,10),tight_layout=True)

ax = plt.subplot(111)
ax.set_xlabel("numéro atomique Z")
ax.set_ylabel("nombre de neutrons N")
ax.set_title("Diagramme de Segrè des nucléides", fontsize=16, y=1.01)
ax.set_xlim(0,Zmax+1)
ax.set_ylim(0,Nmax+1)

trace(noyaux_stables, c_stables, 'stables')
trace(noyaux_alpha, c_alpha, r'alpha ($\alpha$)')
trace(noyaux_beta_p, c_beta_p, r'beta + ($\beta^+$)')
trace(noyaux_beta_m, c_beta_m, r'beta - ($\beta^-$)')
trace(noyaux_capt_e, c_capt_e, 'capture électronique')
trace(noyaux_em_proton, c_em_proton, 'émission de proton')
trace(noyaux_em_neutron, c_em_neutron, 'émission de neutron')
trace(noyaux_fission, c_fission, 'fission spontanée')

# 1e bissectrice
ax.plot([0,120],[0,120],lw=0.5,c='gray', zorder=-1)

if graduations==True:
    loc = ticker.MultipleLocator(base=5)
    ax.xaxis.set_minor_locator(loc)
    ax.yaxis.set_minor_locator(loc)
    ax.grid(which='minor', color='#dddddd')
    ax.grid(which='major', color='#888888', lw=1)
    ax.set_axisbelow(True)

ax.legend(markerscale=4)

ax.text(0.99,0.01,f'{effectif} noyaux', ha='right', transform=ax.transAxes)
texte1='D. Alberto (www.astrolabe-science.fr)'
texte2='données : Atomic Mass Evaluation 2016 Chinese Physics C 41, 030002 (2016), NuBase 2016 Chinese Physics C 41, 030001 (2016)'
ax.text(1.01,0.0,texte1+'     '+texte2,
        transform=ax.transAxes, rotation=90,
        fontsize=7)

fig.savefig("diagramme_NZ_mode.pdf", dpi=100)
fig.savefig("diagramme_NZ_mode.png", dpi=100)
